# coding: utf-8

"""
    aind-sharepoint-service

     ## aind-sharepoint-service  Service to pull data from Sharepoint.  

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from aind_sharepoint_service_async_client.models.nsb2023_headpost_perform_during import NSB2023HeadpostPerformDuring

class TestNSB2023HeadpostPerformDuring(unittest.TestCase):
    """NSB2023HeadpostPerformDuring unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testNSB2023HeadpostPerformDuring(self):
        """Test NSB2023HeadpostPerformDuring"""
        # inst = NSB2023HeadpostPerformDuring()

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    aind-sharepoint-service

     ## aind-sharepoint-service  Service to pull data from Sharepoint.  

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class LASProtocol(str, Enum):
    """
    Enum class for LASProtocol
    """

    """
    allowed enum values
    """
    N_2103_OPTICAL_PHYSIOLOGY = '2103 - Optical Physiology Mindscope Phase 4'
    N_2104_ELECTROPHYSIOLOGY = '2104 - Electrophysiology Mindscope Phase 4'
    N_2105_CHARACTERIZATION_O = '2105 - Characterization of mouse genetic tools'
    N_2106_ANALYSIS_OF_INTEGR = '2106 - Analysis of Integrated Neuronal Phenotypes'
    N_2107_CIRCUIT_TRACING_AN = '2107 - Circuit tracing and optical physiology of mouse cortex'
    N_2109_ANALYSIS_OF_BRAIN = '2109 - Analysis of brain - wide neural circuits in the mouse'
    N_2110_SPECIFICITY_AND_ST = '2110 - Specificity and Strength of Synaptic Signaling Within and Between Brain Areas'
    N_2112_CHARACTERIZATION_O = '2112 - Characterization of the cell - type - specific molecular adaptations that occur during opioid use'
    N_2113_IN_VITRO_SINGLE_CE = '2113 - In Vitro Single Cell Characterization'
    N_2114_CHARACTERIZATION_O = '2114 - Characterization of transcriptomic cell types and molecular adaptations that occur during psychedelic drug use'
    N_2115_OPTICAL_PHYSIOLOGY = '2115 - Optical Physiology of Mouse Brain Circuits'
    N_2116_MOUSE_BREEDING = '2116 - Mouse Breeding'
    N_2117_OPEN_SCOPE_MINDSCO = '2117 - OpenScope Mindscope animal protocol for Optical Physiology and Neuropixel'
    N_2118_ANIMAL_HOLDING_AND = '2118 - Animal Holding and Procedures'
    N_2119_TRAINING_AND_QUALI = '2119 - Training and qualification of animal users'
    N_2120_ANALYSIS_OF_GENE_E = '2120 - Analysis of Gene Expression - Function and Structure in the Mouse Brain'
    N_2201_INTERROGATING_PROJ = '2201 - Interrogating projections and gene expression of neurons by in situ sequencing'
    N_2202_TESTING_AA_VS_IN_P = '2202 - Testing AAVs in Parkinson\'s mouse models'
    N_2204_PRIMARY_NEURON_AND = '2204 - Primary neuron and brain slice culture from postnatal rodent brain'
    N_2205_OPTIMIZATION_AND_V = '2205 - Optimization and validation of viral vectors'
    N_2207_IN_VITRO_BRAIN_STI = '2207 - In Vitro Brain Stimulation'
    N_2212_INVESTIGATING_BRAI = '2212 - Investigating Brain States'
    N_2301_TESTING_OF_ENHANCE = '2301 - Testing of enhancers and AAV gene therapy vectors'
    N_2304_NEUROSURGERY_BEHAV = '2304 - Neurosurgery & Behavior Training Protocol'
    N_2305_IN_VIVO_BRAIN_STIM = '2305 - In Vivo Brain Stimulation'
    N_2306_PATCHSEQ_CHARACTER = '2306 - Patch-seq characterization of mouse neurons in acute brain slices for cross-species comparison studies'
    N_2307_DISSECTING_THE_NEU = '2307 - Dissecting the neural circuits of adaptive control of behavior'
    N_2308_INDUCTION_OF_IMMUN = '2308 - Induction of Immune Memory'
    N_2401_THE_USE_OF_MICE_FO = '2401 - The use of mice for the development of biological recorders'
    N_2402_BRAIN_OBSERVATORY = '2402 - Brain Observatory Optical Physiology'
    N_2405_ANALYSIS_OF_INTEGR = '2405 - Analysis of Integrated Neuronal Phenotypes'
    N_2406_CHARACTERIZATION_OF_MOUS = '2406 - Characterization of mouse and viral genetic tools'
    N_2412_CIRCUIT_TRACING_AND_OPT = '2412 - Circuit tracing and optical physiology of mouse cortex'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of LASProtocol from a JSON string"""
        return cls(json.loads(json_str))





# coding: utf-8

"""
    aind-sharepoint-service

     ## aind-sharepoint-service  Service to pull data from Sharepoint.  

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class NSB2023InitialWorkStation(str, Enum):
    """
    Enum class for Initial Work Station.
    """

    """
    allowed enum values
    """
    SELECT = 'Select...'
    SWS_1 = 'SWS 1'
    SWS_2 = 'SWS 2'
    SWS_3 = 'SWS 3'
    SWS_4 = 'SWS 4'
    SWS_5 = 'SWS 5'
    SWS_6 = 'SWS 6'
    SWS_7 = 'SWS 7'
    SWS_8 = 'SWS 8'
    SWS_9 = 'SWS 9'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of NSB2023InitialWorkStation from a JSON string"""
        return cls(json.loads(json_str))





# coding: utf-8

"""
    aind-sharepoint-service

     ## aind-sharepoint-service  Service to pull data from Sharepoint.  

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class NSB2023FiberImplant6Length(str, Enum):
    """
    Enum class for Fiber Implant6 Length.
    """

    """
    allowed enum values
    """
    SELECT = 'Select...'
    N_1_0_MM = '1.0 mm'
    N_1_5_MM = '1.5 mm'
    N_2_0_MM = '2.0 mm'
    N_2_5_MM = '2.5 mm'
    N_3_0_MM = '3.0 mm'
    N_3_5_MM = '3.5 mm'
    N_4_0_MM = '4.0 mm'
    N_4_5_MM = '4.5 mm'
    N_5_0_MM = '5.0 mm'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of NSB2023FiberImplant6Length from a JSON string"""
        return cls(json.loads(json_str))


